/*  Copyright <2018> <Megumi Iwata>
 *  Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), 
 *  to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 *  and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *  The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
 *  WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *  
 *  
 * CapitiveSense Library Demo Sketch
 * Paul Badger 2008
 * Uses a high value resistor e.g. 10M between send pin and receive pin
 * Resistor effects sensitivity, experiment with values, 50K - 50M. Larger resistor values yield larger sensor values.
 * Receive pin is the sensor pin - try different amounts of foil/metal on this pin
 * 
 *  Connected to output baord (led, neopixel)
 *  modified by Megumi Iwata on 13.06.2018
 */

#include <CapacitiveSensor.h>

int conPin = 6;  // pin6 is connected to the output board pin0
int threshold = 1000;   // threshold of capactive sensor
int oldtotal;          // previous value of capacitive sensor
int state = HIGH;      // the initial state of the output pin

CapacitiveSensor   cs_3_2 = CapacitiveSensor(3,2);        // 10M resistor between pins 4 & 2, pin 2 is sensor pin, add a wire and or foil if desired

void setup()                    
{
   
   cs_3_2.set_CS_AutocaL_Millis(0xFFFFFFFF);     // turn off autocalibrate on channel 1 - just as an example
   pinMode(conPin, OUTPUT);
  
}

void loop()                    
{
    long start = millis();
    long total =  cs_3_2.capacitiveSensor(30);      // sensor value

    if (total > threshold && oldtotal < threshold) {    // use the value only when the value goes LOW to HIGH
      if (state == HIGH)   // change the state ON/OFF
         state = LOW;
       else
         state = HIGH;

      digitalWrite (conPin, state);   
     
    }
    
    oldtotal = total;      // update the old value
    delay(100);
}
