
/*  Copyright <2018> <Megumi Iwata>
 *  Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), 
 *  to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 *  and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *  The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, 
 *  WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *       
 *       
 *  Simple Stepper Motor Control Exaple Code
 *      
 *  by Dejan Nedelkovski, www.HowToMechatronics.com
 *  
 * CapitiveSense Library Demo Sketch
 * Paul Badger 2008
 * Uses a high value resistor e.g. 10M between send pin and receive pin
 * Resistor effects sensitivity, experiment with values, 50K - 50M. Larger resistor values yield larger sensor values.
 * Receive pin is the sensor pin - try different amounts of foil/metal on this pin
 * 
 * modified by Megumi Iwata on 11.06.2018
 */

#include <CapacitiveSensor.h>
CapacitiveSensor   cs_5_4 = CapacitiveSensor(5,4);        
// 10M resistor between pins 4 & 2, pin 2 is sensor pin, add a wire and or foil if desired

// defines pins numbers
const int stepPin = 2; 
const int dirPin = 3;
//const int ledPin = 7; 
const int enablePin = 8;
int threshold = 1000;
int oldtotal;
int state = HIGH;     // the initial state of the output pin
 
void setup() {
  cs_5_4.set_CS_AutocaL_Millis(0xFFFFFFFF);     // turn off autocalibrate on channel 1 - just as an example
  
  pinMode(stepPin,OUTPUT); 
  pinMode(dirPin,OUTPUT);
  pinMode(enablePin, OUTPUT);
 // pinMode(ledPin, OUTPUT);

}

void loop() {
  
    long start = millis();
    long total =  cs_5_4.capacitiveSensor(30);       // sensor value

   digitalWrite(dirPin,HIGH); // Enables the motor to move in a particular direction
        
         
   if (total > threshold && oldtotal < threshold) {    // use the value only when the value goes LOW to HIGH
      
      if (state == HIGH) {       // change the state of enablePin, LOW to run HIGH to stop
         state = LOW;
      } else {
         state = HIGH;
      }
      digitalWrite(enablePin, state);
       }
      
      for(int x = 0; x < 10; x++) {   
        // continue running for 10 steps 
        // use x<10 instead of x<200 (full cycle) to reduce the total time of delay where the code doesn't run
         
         digitalWrite(stepPin, HIGH);
         //digitalWrite(ledPin, HIGH);
         delay(3);
         digitalWrite(stepPin,LOW); 
         //digitalWrite(ledPin, LOW);
         delay(3);
   }
 
  oldtotal = total;      // update the old value
    delay(10);           // total delaytime: running motor (6 millis * 10 = 60 millis) + 10 millis =  70 millis
}

